@@ -8,16 +8,16 @@ require Exporter;
 use warnings;
 use strict;
 use Carp;
-use JSON::Parse 'json_file_to_perl';
+use JSON::Parse 'read_json';
 use Convert::Moji 'make_regex';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 # Load the data from the file.
 
 my $json = __FILE__;
 $json =~ s!\.pm$!/abc.json!;
-my $abc = json_file_to_perl ($json);
+my $abc = read_json ($json);
 
 # American
 my @a;
